@@ -10,11 +10,17 @@ Usage::
     client: CodeStarNotificationsClient = boto3.client("codestar-notifications")
     ```
 """
-import sys
 from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_codestar_notifications.literals import (
+    DetailType,
+    ListEventTypesPaginatorName,
+    ListNotificationRulesPaginatorName,
+    ListTargetsPaginatorName,
+    NotificationRuleStatus,
+)
 from mypy_boto3_codestar_notifications.paginator import (
     ListEventTypesPaginator,
     ListNotificationRulesPaginator,
@@ -37,12 +43,6 @@ from mypy_boto3_codestar_notifications.type_defs import (
     UnsubscribeResultTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("CodeStarNotificationsClient",)
 
 
@@ -85,10 +85,10 @@ class CodeStarNotificationsClient:
         EventTypeIds: List[str],
         Resource: str,
         Targets: List[TargetTypeDef],
-        DetailType: Literal["BASIC", "FULL"],
+        DetailType: DetailType,
         ClientRequestToken: str = None,
         Tags: Dict[str, str] = None,
-        Status: Literal["ENABLED", "DISABLED"] = None,
+        Status: NotificationRuleStatus = None,
     ) -> CreateNotificationRuleResultTypeDef:
         """
         [Client.create_notification_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codestar-notifications.html#CodeStarNotifications.Client.create_notification_rule)
@@ -181,31 +181,31 @@ class CodeStarNotificationsClient:
         self,
         Arn: str,
         Name: str = None,
-        Status: Literal["ENABLED", "DISABLED"] = None,
+        Status: NotificationRuleStatus = None,
         EventTypeIds: List[str] = None,
         Targets: List[TargetTypeDef] = None,
-        DetailType: Literal["BASIC", "FULL"] = None,
+        DetailType: DetailType = None,
     ) -> Dict[str, Any]:
         """
         [Client.update_notification_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codestar-notifications.html#CodeStarNotifications.Client.update_notification_rule)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_event_types"]) -> ListEventTypesPaginator:
+    def get_paginator(self, operation_name: ListEventTypesPaginatorName) -> ListEventTypesPaginator:
         """
         [Paginator.ListEventTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_notification_rules"]
+        self, operation_name: ListNotificationRulesPaginatorName
     ) -> ListNotificationRulesPaginator:
         """
         [Paginator.ListNotificationRules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_targets"]) -> ListTargetsPaginator:
+    def get_paginator(self, operation_name: ListTargetsPaginatorName) -> ListTargetsPaginator:
         """
         [Paginator.ListTargets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets)
         """
